@@ -1,5 +1,5 @@
 ; Scheme 9 from Empty Space, Function Library
-; By Nils M Holm, 2010,2012
+; By Nils M Holm, 2010-2015
 ; Placed in the Public Domain
 ;
 ; (scm2html <option> ...)  ==>  string | unspecific
@@ -126,9 +126,10 @@
           p)))
 
   (define (Epilog)
+    (change-color #f #f #f)
     (let ((p (if lout-mode
-                 '("}}")
-                 '("</SPAN></PRE>"))))
+                 '("}")
+                 '("</PRE>"))))
       (if full-html
           (append p '("</BODY>" "</HTML>"))
           p)))
@@ -203,22 +204,22 @@
           ((and (equal? co *Color*) (eq? bo *Bold*)))
           (else
             (if *Bold*
-                (begin (if lout-mode
-                           (output "}")
-                           (output "</B>"))
-                       (set! *Bold* #f)))
+                (if lout-mode
+                    (output "}")
+                    (output "</B>")))
             (if *Color*
                 (if lout-mode
                     (output "}")
                     (output "</SPAN>")))
-            (if lout-mode
-                (begin (output "@S_")
-                       (output co)
-                       (output "{"))
-                (begin (output "<SPAN class=")
-                       (output co)
-                       (output ">")))
-            (if (and bo (not *Bold*))
+            (if co
+                (if lout-mode
+                    (begin (output "@S_")
+                           (output co)
+                           (output "{"))
+                    (begin (output "<SPAN class=")
+                           (output co)
+                           (output ">"))))
+            (if bo
                 (if lout-mode
                     (output "@B{")
                     (output "<B>")))
